#[repr(i32)]pub enum VEventType {
Show 21 variants
Unknown = 0,
Gtid = 1,
Begin = 2,
Commit = 3,
Rollback = 4,
Ddl = 5,
Insert = 6,
Replace = 7,
Update = 8,
Delete = 9,
Set = 10,
Other = 11,
Row = 12,
Field = 13,
Heartbeat = 14,
Vgtid = 15,
Journal = 16,
Version = 17,
Lastpk = 18,
Savepoint = 19,
CopyCompleted = 20,
}Expand description
VEventType enumerates the event types. Many of these types will not be encountered in RBR mode.
Variants
Unknown = 0
Gtid = 1
Begin = 2
Commit = 3
Rollback = 4
Ddl = 5
Insert = 6
INSERT, REPLACE, UPDATE, DELETE and SET will not be seen in RBR mode.
Replace = 7
Update = 8
Delete = 9
Set = 10
Other = 11
OTHER is a dummy event. If encountered, the current GTID must be recorded by the client to be able to resume.
Row = 12
Field = 13
Heartbeat = 14
HEARTBEAT is sent if there is inactivity. If a client does not receive events beyond the hearbeat interval, it can assume that it’s lost connection to the vstreamer.
Vgtid = 15
VGTID is generated by VTGate’s VStream that combines multiple GTIDs.
Journal = 16
Version = 17
Lastpk = 18
Savepoint = 19
CopyCompleted = 20
COPY_COMPLETED is sent when VTGate’s VStream copy operation is done. If a client experiences some disruptions before receiving the event, the client should restart the copy operation.
Implementations
Sourceimpl VEventType
impl VEventType
Sourceimpl VEventType
impl VEventType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.