#[repr(i32)]pub enum VReplicationWorkflowType {
Materialize = 0,
MoveTables = 1,
CreateLookupIndex = 2,
Migrate = 3,
Reshard = 4,
OnlineDdl = 5,
}Expand description
VReplicationWorkflowType define types of vreplication workflows.
Variants
Implementations
Sourceimpl VReplicationWorkflowType
impl VReplicationWorkflowType
Sourcepub fn is_valid(value: i32) -> bool
pub fn is_valid(value: i32) -> bool
Returns true if value is a variant of VReplicationWorkflowType.
Sourcepub fn from_i32(value: i32) -> Option<VReplicationWorkflowType>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<VReplicationWorkflowType>
Converts an i32 to a VReplicationWorkflowType, or None if value is not a valid variant.
Sourceimpl VReplicationWorkflowType
impl VReplicationWorkflowType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.