Struct BinlogSource

pub struct BinlogSource {
    pub keyspace: String,
    pub shard: String,
    pub tablet_type: i32,
    pub key_range: Option<KeyRange>,
    pub tables: Vec<String>,
    pub filter: Option<Filter>,
    pub on_ddl: i32,
    pub external_mysql: String,
    pub stop_after_copy: bool,
    pub external_cluster: String,
    pub source_time_zone: String,
    pub target_time_zone: String,
}
BinlogSource specifies the source and filter parameters for Filtered Replication. KeyRange and Tables are legacy. Filter is the new way to specify the filtering rules.

Fields

keyspace: String

the source keyspace

shard: String

the source shard

tablet_type: i32

the source tablet type

key_range: Option<KeyRange>

KeyRange is set if the request is for a keyrange

tables: Vec<String>

Tables is set if the request is for a list of tables

filter: Option<Filter>

Filter is set if we’re using the generalized representation for the filter.

on_ddl: i32

OnDdl specifies the action to be taken when a DDL is encountered.

external_mysql: String

Source is an external mysql. This attribute should be set to the username to use in the connection

stop_after_copy: bool

StopAfterCopy specifies if vreplication should be stopped after copying is done.

external_cluster: String

ExternalCluster is the name of the mounted cluster which has the source keyspace/db for this workflow it is of the type <cluster_type.cluster_name>

source_time_zone: String

SourceTimeZone is the time zone in which datetimes on the source were stored, provided as an option in MoveTables

target_time_zone: String

TargetTimeZone is not currently specifiable by the user, defaults to UTC for the forward workflows and to the SourceTimeZone in reverse workflows

Implementations

Source

impl BinlogSource

pub fn tablet_type(&self) -> TabletType

Returns the enum value of tablet_type, or the default if the field is set to an invalid enum value.

pub fn set_tablet_type(&mut self, value: TabletType)

Sets tablet_type to the provided enum value.

pub fn on_ddl(&self) -> OnDdlAction

Returns the enum value of on_ddl, or the default if the field is set to an invalid enum value.

pub fn set_on_ddl(&mut self, value: OnDdlAction)

Sets on_ddl to the provided enum value.