pub struct Filter {
pub rules: Vec<Rule>,
pub field_event_mode: i32,
pub workflow_type: i64,
pub workflow_name: String,
}Expand description
Filter represents a list of ordered rules. The first match wins.
Fields
rules: Vec<Rule>field_event_mode: i32FieldEventMode specifies the behavior if there is a mismatch between the current schema and the fields in the binlog. This can happen if the binlog position is before a DDL that would cause the fields to change. If vstreamer detects such an inconsistency, the behavior depends on the FieldEventMode. If the value is ERR_ON_MISMATCH (default), then it errors out. If it’s BEST_EFFORT, it sends a field event with fake column names as “@1”, “@2”, etc.
workflow_type: i64workflow_name: StringImplementations
Sourceimpl Filter
impl Filter
Sourcepub fn field_event_mode(&self) -> FieldEventMode
pub fn field_event_mode(&self) -> FieldEventMode
Returns the enum value of field_event_mode, or the default if the field is set to an invalid enum value.
Sourcepub fn set_field_event_mode(&mut self, value: FieldEventMode)
pub fn set_field_event_mode(&mut self, value: FieldEventMode)
Sets field_event_mode to the provided enum value.