pub struct VStreamRequest {
pub effective_caller_id: Option<CallerId>,
pub immediate_caller_id: Option<VtGateCallerId>,
pub target: Option<Target>,
pub position: String,
pub filter: Option<Filter>,
pub table_last_p_ks: Vec<TableLastPk>,
}Expand description
VStreamRequest is the payload for VStreamer
Fields
effective_caller_id: Option<CallerId>immediate_caller_id: Option<VtGateCallerId>target: Option<Target>position: Stringfilter: Option<Filter>table_last_p_ks: Vec<TableLastPk>Trait Implementations
Sourceimpl Clone for VStreamRequest
impl Clone for VStreamRequest
Sourcefn clone(&self) -> VStreamRequest
fn clone(&self) -> VStreamRequest
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VStreamRequest
impl Debug for VStreamRequest
Sourceimpl Default for VStreamRequest
impl Default for VStreamRequest
Sourceimpl Message for VStreamRequest
impl Message for VStreamRequest
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode<B>(buf: B) -> Result<Self, DecodeError>
fn decode<B>(buf: B) -> Result<Self, DecodeError>
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
fn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for VStreamRequest
impl PartialEq for VStreamRequest
impl StructuralPartialEq for VStreamRequest