pub struct VStreamTablesResponse {
pub table_name: String,
pub fields: Vec<Field>,
pub pkfields: Vec<Field>,
pub gtid: String,
pub rows: Vec<Row>,
pub lastpk: Option<Row>,
}Expand description
VStreamTablesResponse is the response from VStreamTables
Fields
table_name: Stringfields: Vec<Field>pkfields: Vec<Field>gtid: Stringrows: Vec<Row>lastpk: Option<Row>Trait Implementations
Sourceimpl Clone for VStreamTablesResponse
impl Clone for VStreamTablesResponse
Sourcefn clone(&self) -> VStreamTablesResponse
fn clone(&self) -> VStreamTablesResponse
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VStreamTablesResponse
impl Debug for VStreamTablesResponse
Sourceimpl Default for VStreamTablesResponse
impl Default for VStreamTablesResponse
Sourceimpl Message for VStreamTablesResponse
impl Message for VStreamTablesResponse
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode<B>(buf: B) -> Result<Self, DecodeError>
fn decode<B>(buf: B) -> Result<Self, DecodeError>
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
fn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for VStreamTablesResponse
impl PartialEq for VStreamTablesResponse
impl StructuralPartialEq for VStreamTablesResponse