#[repr(i32)]pub enum TransactionState {
Unknown = 0,
Prepare = 1,
Commit = 2,
Rollback = 3,
}Expand description
TransactionState represents the state of a distributed transaction.
Variants
Implementations
Sourceimpl TransactionState
impl TransactionState
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.