#[repr(i32)]pub enum TransactionIsolation {
Default = 0,
RepeatableRead = 1,
ReadCommitted = 2,
ReadUncommitted = 3,
Serializable = 4,
ConsistentSnapshotReadOnly = 5,
Autocommit = 6,
}Variants
Default = 0
RepeatableRead = 1
ReadCommitted = 2
ReadUncommitted = 3
Serializable = 4
ConsistentSnapshotReadOnly = 5
This is not an “official” transaction level but it will do a START TRANSACTION WITH CONSISTENT SNAPSHOT, READ ONLY
Autocommit = 6
This not an “official” transaction level, it will send queries to mysql without wrapping them in a transaction
Implementations
Sourceimpl TransactionIsolation
impl TransactionIsolation
Sourcepub fn is_valid(value: i32) -> bool
pub fn is_valid(value: i32) -> bool
Returns true if value is a variant of TransactionIsolation.
Sourcepub fn from_i32(value: i32) -> Option<TransactionIsolation>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<TransactionIsolation>
Converts an i32 to a TransactionIsolation, or None if value is not a valid variant.
Sourceimpl TransactionIsolation
impl TransactionIsolation
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.