pub struct AggregateStats {
pub healthy_tablet_count: i32,
pub unhealthy_tablet_count: i32,
pub replication_lag_seconds_min: u32,
pub replication_lag_seconds_max: u32,
}Expand description
AggregateStats contains information about the health of a group of tablets for a Target. It is used to propagate stats from a vtgate to another, or from the Gateway layer of a vtgate to the routing layer.
Fields
healthy_tablet_count: i32healthy_tablet_count is the number of healthy tablets in the group.
unhealthy_tablet_count: i32unhealthy_tablet_count is the number of unhealthy tablets in the group.
replication_lag_seconds_min: u32replication_lag_seconds_min is the minimum of the replication_lag_seconds values of the healthy tablets. It is unset if the tablet type is primary.
replication_lag_seconds_max: u32replication_lag_seconds_max is the maximum of the replication_lag_seconds values of the healthy tablets. It is unset if the tablet type is primary.