pub struct EventToken {
pub timestamp: i64,
pub shard: String,
pub position: String,
}Expand description
EventToken is a structure that describes a point in time in a replication stream on one shard. The most recent known replication position can be retrieved from vttablet when executing a query. It is also sent with the replication streams from the binlog service.
Fields
timestamp: i64timestamp is the MySQL timestamp of the statements. Seconds since Epoch.
shard: StringThe shard name that applied the statements. Note this is not set when streaming from a vttablet. It is only used on the client -> vtgate link.
position: StringThe position on the replication stream after this statement was applied. It is not the transaction ID / GTID, but the position / GTIDSet.