Struct ExecuteOptions

pub struct ExecuteOptions {
    pub included_fields: i32,
    pub client_found_rows: bool,
    pub workload: i32,
    pub sql_select_limit: i64,
    pub transaction_isolation: i32,
    pub skip_query_plan_cache: bool,
    pub planner_version: i32,
    pub has_created_temp_tables: bool,
    pub consolidator: i32,
    pub transaction_access_mode: Vec<i32>,
    pub workload_name: String,
    pub priority: String,
}
ExecuteOptions is passed around for all Execute calls.

Fields

included_fields: i32

Controls what fields are returned in Field message responses from mysql, i.e. field name, table name, etc. This is an optimization for high-QPS queries where the client knows what it’s getting

client_found_rows: bool

client_rows_found specifies if rows_affected should return rows found instead of rows affected. Behavior is defined by MySQL’s CLIENT_FOUND_ROWS flag.

workload: i32

workload specifies the type of workload: OLTP: DMLs allowed, results have row count limit, and query timeouts are shorter. OLAP: DMLS not allowed, no limit on row count, timeouts can be as high as desired. DBA: no limit on rowcount or timeout, all queries allowed but intended for long DMLs and DDLs.

sql_select_limit: i64

sql_select_limit sets an implicit limit on all select statements. Since vitess also sets a rowcount limit on queries, the smallest value wins.

transaction_isolation: i32skip_query_plan_cache: bool

skip_query_plan_cache specifies if the query plan should be cached by vitess. By default all query plans are cached.

planner_version: i32

PlannerVersion specifies which planner to use. If DEFAULT is chosen, whatever vtgate was started with will be used

has_created_temp_tables: bool

has_created_temp_tables signals whether plans created in this session should be cached or not if the user has created temp tables, Vitess will not reuse plans created for this session in other sessions. The current session can still use other sessions cached plans.

consolidator: i32transaction_access_mode: Vec<i32>

TransactionAccessMode specifies the access modes to be used while starting the transaction i.e. READ WRITE/READ ONLY/WITH CONSISTENT SNAPSHOT If not specified, the transaction will be started with the default access mode on the connection.

workload_name: String

WorkloadName specifies the name of the workload as indicated in query directives. This is used for instrumentation in metrics and tracing spans.

priority: String

priority specifies the priority of the query, between 0 and 100. This is leveraged by the transaction throttler to determine whether, under resource contention, a query should or should not be throttled.

Implementations

Source

impl ExecuteOptions

pub fn included_fields(&self) -> IncludedFields

Returns the enum value of included_fields, or the default if the field is set to an invalid enum value.

pub fn set_included_fields(&mut self, value: IncludedFields)

Sets included_fields to the provided enum value.

pub fn workload(&self) -> Workload

Returns the enum value of workload, or the default if the field is set to an invalid enum value.

pub fn set_workload(&mut self, value: Workload)

Sets workload to the provided enum value.

pub fn transaction_isolation(&self) -> TransactionIsolation

Returns the enum value of transaction_isolation, or the default if the field is set to an invalid enum value.

pub fn set_transaction_isolation(&mut self, value: TransactionIsolation)

Sets transaction_isolation to the provided enum value.

pub fn planner_version(&self) -> PlannerVersion

Returns the enum value of planner_version, or the default if the field is set to an invalid enum value.

pub fn set_planner_version(&mut self, value: PlannerVersion)

Sets planner_version to the provided enum value.

pub fn consolidator(&self) -> Consolidator

Returns the enum value of consolidator, or the default if the field is set to an invalid enum value.

pub fn set_consolidator(&mut self, value: Consolidator)

Sets consolidator to the provided enum value.

pub fn transaction_access_mode( &self, ) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<TransactionAccessMode>>

Returns an iterator which yields the valid enum values contained in transaction_access_mode.

pub fn push_transaction_access_mode(&mut self, value: TransactionAccessMode)

Appends the provided enum value to transaction_access_mode.