pub struct Field {
pub name: String,
pub type: i32,
pub table: String,
pub org_table: String,
pub database: String,
pub org_name: String,
pub column_length: u32,
pub charset: u32,
pub decimals: u32,
pub flags: u32,
pub column_type: String,
}Expand description
Field describes a single column returned by a query
Fields
name: Stringname of the field as returned by mysql C API
type: i32vitess-defined type. Conversion function is in sqltypes package.
table: StringRemaining fields from mysql C API. These fields are only populated when ExecuteOptions.included_fields is set to IncludedFields.ALL.
org_table: Stringdatabase: Stringorg_name: Stringcolumn_length: u32column_length is really a uint32. All 32 bits can be used.
charset: u32charset is actually a uint16. Only the lower 16 bits are used.
decimals: u32decimals is actually a uint8. Only the lower 8 bits are used.
flags: u32flags is actually a uint16. Only the lower 16 bits are used.
column_type: Stringcolumn_type is optionally populated from information_schema.columns
Implementations