Struct RealtimeStats

pub struct RealtimeStats {
    pub health_error: String,
    pub replication_lag_seconds: u32,
    pub binlog_players_count: i32,
    pub filtered_replication_lag_seconds: i64,
    pub cpu_usage: f64,
    pub qps: f64,
    pub table_schema_changed: Vec<String>,
    pub view_schema_changed: Vec<String>,
}
RealtimeStats contains information about the tablet status. It is only valid for a single tablet.

Fields

health_error: String

health_error is the last error we got from health check, or empty is the server is healthy. This is used for subset selection, we do not send queries to servers that are not healthy.

replication_lag_seconds: u32

replication_lag_seconds is populated for replicas only. It indicates how far behind on (MySQL) replication a replica currently is. It is used by clients for subset selection (so we don’t try to send traffic to tablets that are too far behind). NOTE: This field must not be evaluated if “health_error” is not empty. TODO(mberlin): Let’s switch it to int64 instead?

binlog_players_count: i32

bin_log_players_count is the number of currently running binlog players. if the value is 0, it means that filtered replication is currently not running on the tablet. If >0, filtered replication is running. NOTE: This field must not be evaluated if “health_error” is not empty.

filtered_replication_lag_seconds: i64

filtered_replication_lag_seconds is populated for the receiving primary of an ongoing filtered replication only. It specifies how far the receiving primary lags behind the sending primary. NOTE: This field must not be evaluated if “health_error” is not empty. NOTE: This field must not be evaluated if “bin_log_players_count” is 0.

cpu_usage: f64

cpu_usage is used for load-based balancing

qps: f64

qps is the average QPS (queries per second) rate in the last XX seconds where XX is usually 60 (See query_service_stats.go).

table_schema_changed: Vec<String>

table_schema_changed is to provide list of tables that have schema changes detected by the tablet.

view_schema_changed: Vec<String>

view_schema_changed is to provide list of views that have schema changes detected by the tablet.