pub struct ReserveBeginStreamExecuteRequest {
pub effective_caller_id: Option<CallerId>,
pub immediate_caller_id: Option<VtGateCallerId>,
pub target: Option<Target>,
pub query: Option<BoundQuery>,
pub options: Option<ExecuteOptions>,
pub pre_queries: Vec<String>,
pub post_begin_queries: Vec<String>,
}Expand description
ReserveBeginStreamExecuteRequest is the payload to ReserveBeginStreamExecute
Fields
effective_caller_id: Option<CallerId>immediate_caller_id: Option<VtGateCallerId>target: Option<Target>query: Option<BoundQuery>options: Option<ExecuteOptions>pre_queries: Vec<String>post_begin_queries: Vec<String>Trait Implementations
Sourceimpl Clone for ReserveBeginStreamExecuteRequest
impl Clone for ReserveBeginStreamExecuteRequest
Sourcefn clone(&self) -> ReserveBeginStreamExecuteRequest
fn clone(&self) -> ReserveBeginStreamExecuteRequest
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Message for ReserveBeginStreamExecuteRequest
impl Message for ReserveBeginStreamExecuteRequest
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode<B>(buf: B) -> Result<Self, DecodeError>
fn decode<B>(buf: B) -> Result<Self, DecodeError>
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
fn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for ReserveBeginStreamExecuteRequest
impl PartialEq for ReserveBeginStreamExecuteRequest
Sourcefn eq(&self, other: &ReserveBeginStreamExecuteRequest) -> bool
fn eq(&self, other: &ReserveBeginStreamExecuteRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ReserveBeginStreamExecuteRequest