pub struct ReserveBeginStreamExecuteResponse {
pub error: Option<RpcError>,
pub result: Option<QueryResult>,
pub transaction_id: i64,
pub reserved_id: i64,
pub tablet_alias: Option<TabletAlias>,
pub session_state_changes: String,
}Expand description
ReserveBeginStreamExecuteResponse is the returned value from ReserveBeginStreamExecute
Fields
error: Option<RpcError>error contains an application level error if necessary. Note the transaction_id may be set, even when an error is returned, if the begin worked but the stream execute failed.
result: Option<QueryResult>transaction_id: i64The following fields might be non-zero even if an error is present.
reserved_id: i64tablet_alias: Option<TabletAlias>session_state_changes: StringThe session_state_changes might be set if the transaction is a snapshot transaction and the MySQL implementation supports getting a start gtid on snapshot