pub struct ResultWithError {
pub error: Option<RpcError>,
pub result: Option<QueryResult>,
}Expand description
ResultWithError represents a query response in the form of result or error but not both. TODO: To be used in ExecuteBatchResponse and BeginExecuteBatchResponse.
Fields
error: Option<RpcError>error contains an query level error, only set if result is unset.
result: Option<QueryResult>result contains the query result, only set if error is unset.