pub struct StreamEvent {
pub statements: Vec<Statement>,
pub event_token: Option<EventToken>,
}Expand description
StreamEvent describes a set of transformations that happened as a single transactional unit on a server. It is streamed back by the Update Stream calls.
Fields
statements: Vec<Statement>The statements in this transaction.
event_token: Option<EventToken>The Event Token for this event.