Struct StreamHealthResponse

pub struct StreamHealthResponse {
    pub target: Option<Target>,
    pub serving: bool,
    pub primary_term_start_timestamp: i64,
    pub realtime_stats: Option<RealtimeStats>,
    pub tablet_alias: Option<TabletAlias>,
}
StreamHealthResponse is streamed by StreamHealth on a regular basis. It is expected to be used between a vtgate and vttablet:

  • target describes the tablet.
  • realtime_stats is set.
  • aggregate_stats is not set (deprecated)

Fields

target: Option<Target>

target is the current server type. Only queries with that exact Target record will be accepted (the cell may not match, however).

serving: bool

serving is true iff the tablet is serving. A tablet may not be serving if filtered replication is enabled on a primary for instance, or if a replica should not be used because the keyspace is being resharded.

primary_term_start_timestamp: i64

primary_term_start_timestamp can be interpreted as the last time we knew that this tablet was promoted to a PRIMARY of this shard (if StreamHealthResponse describes a group of tablets, between two vtgates, only one primary will be present in the group, and this is this primary’s value).

It is used by vtgate when determining the current PRIMARY of a shard. If vtgate sees more than one PRIMARY tablet, this timestamp is used as tiebreaker where the PRIMARY with the highest timestamp wins. Another usage of this timestamp is in go/vt/vtgate/buffer to detect the end of a reparent (failover) and stop buffering.

In practice, this field is set to: a) the last time the RPC tabletmanager.TabletExternallyReparented was called on this tablet (usually done by an external failover tool e.g. Orchestrator). The failover tool can call this as long as we are the primary i.e. even ages after the last reparent occurred. OR b) the last time an active reparent was executed through a vtctl command (InitShardPrimary, PlannedReparentShard, EmergencyReparentShard) OR c) the last time vttablet was started and it initialized its tablet type as PRIMARY because it was recorded as the shard’s current primary in the topology (see go/vt/vttablet/tabletmanager/init_tablet.go) OR d) 0 if the vttablet is not a PRIMARY.

realtime_stats: Option<RealtimeStats>

realtime_stats contains information about the tablet status. It is only filled in if the information is about a tablet.

tablet_alias: Option<TabletAlias>

tablet_alias is the alias of the sending tablet. The discovery/healthcheck.go code uses it to verify that it’s talking to the correct tablet and that it hasn’t changed in the meantime e.g. due to tablet restarts where ports or ips have been reused but assigned differently.