Struct Target

pub struct Target {
    pub keyspace: String,
    pub shard: String,
    pub tablet_type: i32,
    pub cell: String,
}
Target describes what the client expects the tablet is. If the tablet does not match, an error is returned.

Fields

keyspace: Stringshard: Stringtablet_type: i32cell: String

cell is used for routing queries between vtgate and vttablets. It is not used when Target is part of the Session sent by the client.

Implementations

Source

impl Target

pub fn tablet_type(&self) -> TabletType

Returns the enum value of tablet_type, or the default if the field is set to an invalid enum value.

pub fn set_tablet_type(&mut self, value: TabletType)

Sets tablet_type to the provided enum value.