#[repr(i32)]pub enum StopReplicationMode {
Ioandsqlthread = 0,
Iothreadonly = 1,
}Expand description
StopReplicationMode is used to provide controls over how replication is stopped.
Variants
Implementations
Sourceimpl StopReplicationMode
impl StopReplicationMode
Sourcepub fn from_i32(value: i32) -> Option<StopReplicationMode>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<StopReplicationMode>
Converts an i32 to a StopReplicationMode, or None if value is not a valid variant.
Sourceimpl StopReplicationMode
impl StopReplicationMode
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.