pub struct FullStatus {Show 21 fields
pub server_id: u32,
pub server_uuid: String,
pub replication_status: Option<Status>,
pub primary_status: Option<PrimaryStatus>,
pub gtid_purged: String,
pub version: String,
pub version_comment: String,
pub read_only: bool,
pub gtid_mode: String,
pub binlog_format: String,
pub binlog_row_image: String,
pub log_bin_enabled: bool,
pub log_replica_updates: bool,
pub semi_sync_primary_enabled: bool,
pub semi_sync_replica_enabled: bool,
pub semi_sync_primary_status: bool,
pub semi_sync_replica_status: bool,
pub semi_sync_primary_clients: u32,
pub semi_sync_primary_timeout: u64,
pub semi_sync_wait_for_replica_count: u32,
pub super_read_only: bool,
}Expand description
FullStatus contains the full status of MySQL including the replication information, semi-sync information, GTID information among others
Fields
server_id: u32server_uuid: Stringreplication_status: Option<Status>primary_status: Option<PrimaryStatus>gtid_purged: Stringversion: Stringversion_comment: Stringread_only: boolgtid_mode: Stringbinlog_format: Stringbinlog_row_image: Stringlog_bin_enabled: boollog_replica_updates: boolsemi_sync_primary_enabled: boolsemi_sync_replica_enabled: boolsemi_sync_primary_status: boolsemi_sync_replica_status: boolsemi_sync_primary_clients: u32semi_sync_primary_timeout: u64semi_sync_wait_for_replica_count: u32super_read_only: boolTrait Implementations
Sourceimpl Clone for FullStatus
impl Clone for FullStatus
Sourcefn clone(&self) -> FullStatus
fn clone(&self) -> FullStatus
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FullStatus
impl Debug for FullStatus
Sourceimpl Default for FullStatus
impl Default for FullStatus
Sourceimpl Message for FullStatus
impl Message for FullStatus
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode<B>(buf: B) -> Result<Self, DecodeError>
fn decode<B>(buf: B) -> Result<Self, DecodeError>
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
fn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for FullStatus
impl PartialEq for FullStatus
impl StructuralPartialEq for FullStatus