pub struct Status {Show 22 fields
pub position: String,
pub replication_lag_seconds: u32,
pub source_host: String,
pub source_port: i32,
pub connect_retry: i32,
pub relay_log_position: String,
pub file_position: String,
pub relay_log_source_binlog_equivalent_position: String,
pub source_server_id: u32,
pub source_uuid: String,
pub io_state: i32,
pub last_io_error: String,
pub sql_state: i32,
pub last_sql_error: String,
pub relay_log_file_position: String,
pub source_user: String,
pub sql_delay: u32,
pub auto_position: bool,
pub using_gtid: bool,
pub has_replication_filters: bool,
pub ssl_allowed: bool,
pub replication_lag_unknown: bool,
}Expand description
Status is the replication status for MySQL/MariaDB/File-based. Returned by a flavor-specific command and parsed into a Position and fields.
Fields
position: Stringreplication_lag_seconds: u32source_host: Stringsource_port: i32connect_retry: i32relay_log_position: StringRelayLogPosition will be empty for flavors that do not support returning the full GTIDSet from the relay log, such as MariaDB.
file_position: Stringrelay_log_source_binlog_equivalent_position: Stringsource_server_id: u32source_uuid: Stringio_state: i32last_io_error: Stringsql_state: i32last_sql_error: Stringrelay_log_file_position: Stringsource_user: Stringsql_delay: u32auto_position: boolusing_gtid: boolhas_replication_filters: boolssl_allowed: boolreplication_lag_unknown: boolTrait Implementations
Sourceimpl Message for Status
impl Message for Status
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode<B>(buf: B) -> Result<Self, DecodeError>
fn decode<B>(buf: B) -> Result<Self, DecodeError>
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
fn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.impl StructuralPartialEq for Status