pub struct Stream {Show 14 fields
pub id: i32,
pub bls: Option<BinlogSource>,
pub pos: String,
pub stop_pos: String,
pub max_tps: i64,
pub max_replication_lag: i64,
pub time_updated: Option<Time>,
pub transaction_timestamp: Option<Time>,
pub state: i32,
pub message: String,
pub rows_copied: i64,
pub time_heartbeat: Option<Time>,
pub time_throttled: Option<Time>,
pub component_throttled: String,
}Fields
id: i32bls: Option<BinlogSource>pos: Stringstop_pos: Stringmax_tps: i64max_replication_lag: i64time_updated: Option<Time>transaction_timestamp: Option<Time>state: i32message: Stringrows_copied: i64time_heartbeat: Option<Time>time_throttled: Option<Time>component_throttled: StringImplementations
Sourceimpl Stream
impl Stream
Sourcepub fn state(&self) -> VReplicationWorkflowState
pub fn state(&self) -> VReplicationWorkflowState
Returns the enum value of state, or the default if the field is set to an invalid enum value.
Sourcepub fn set_state(&mut self, value: VReplicationWorkflowState)
pub fn set_state(&mut self, value: VReplicationWorkflowState)
Sets state to the provided enum value.