pub struct BackupRequest {
pub concurrency: i64,
pub allow_primary: bool,
pub incremental_from_pos: String,
pub upgrade_safe: bool,
}Fields
concurrency: i64allow_primary: boolincremental_from_pos: StringIncrementalFromPos indicates a position of a previous backup. When this value is non-empty then the backup becomes incremental and applies as of given position.
upgrade_safe: boolUpgradeSafe indicates if the backup should be taken with innodb_fast_shutdown=0 so that it’s a backup that can be used for an upgrade.