pub struct PreflightSchemaResponse {
pub change_results: Vec<SchemaChangeResult>,
}Fields
change_results: Vec<SchemaChangeResult>change_results has for each change the schema before and after it. The number of elements is identical to the length of “changes” in the request.