pub struct ReadVReplicationWorkflowResponse {
pub workflow: String,
pub cells: String,
pub tablet_types: Vec<i32>,
pub tablet_selection_preference: i32,
pub db_name: String,
pub tags: String,
pub workflow_type: i32,
pub workflow_sub_type: i32,
pub defer_secondary_keys: bool,
pub streams: Vec<Stream>,
}Fields
workflow: Stringcells: Stringtablet_types: Vec<i32>tablet_selection_preference: i32db_name: Stringworkflow_type: i32workflow_sub_type: i32defer_secondary_keys: boolstreams: Vec<Stream>Implementations
Sourceimpl ReadVReplicationWorkflowResponse
impl ReadVReplicationWorkflowResponse
Sourcepub fn tablet_types(
&self,
) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<TabletType>>
pub fn tablet_types( &self, ) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<TabletType>>
Returns an iterator which yields the valid enum values contained in tablet_types.
Sourcepub fn push_tablet_types(&mut self, value: TabletType)
pub fn push_tablet_types(&mut self, value: TabletType)
Appends the provided enum value to tablet_types.
Sourcepub fn tablet_selection_preference(&self) -> TabletSelectionPreference
pub fn tablet_selection_preference(&self) -> TabletSelectionPreference
Returns the enum value of tablet_selection_preference, or the default if the field is set to an invalid enum value.
Sourcepub fn set_tablet_selection_preference(
&mut self,
value: TabletSelectionPreference,
)
pub fn set_tablet_selection_preference( &mut self, value: TabletSelectionPreference, )
Sets tablet_selection_preference to the provided enum value.
Sourcepub fn workflow_type(&self) -> VReplicationWorkflowType
pub fn workflow_type(&self) -> VReplicationWorkflowType
Returns the enum value of workflow_type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_workflow_type(&mut self, value: VReplicationWorkflowType)
pub fn set_workflow_type(&mut self, value: VReplicationWorkflowType)
Sets workflow_type to the provided enum value.
Sourcepub fn workflow_sub_type(&self) -> VReplicationWorkflowSubType
pub fn workflow_sub_type(&self) -> VReplicationWorkflowSubType
Returns the enum value of workflow_sub_type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_workflow_sub_type(&mut self, value: VReplicationWorkflowSubType)
pub fn set_workflow_sub_type(&mut self, value: VReplicationWorkflowSubType)
Sets workflow_sub_type to the provided enum value.