pub struct ReloadSchemaRequest {
pub wait_position: String,
}Fields
wait_position: Stringwait_position allows scheduling a schema reload to occur after a given DDL has replicated to this server, by specifying a replication position to wait for. Leave empty to trigger the reload immediately.