pub struct RestoreFromBackupRequest {
pub backup_time: Option<Time>,
pub restore_to_pos: String,
pub dry_run: bool,
pub restore_to_timestamp: Option<Time>,
}Fields
backup_time: Option<Time>restore_to_pos: StringRestoreToPos indicates a position for a point-in-time recovery. The recovery is expected to utilize one full backup, followed by zero or more incremental backups, that reach the precise desired position
dry_run: boolDry run does not actually performs the restore, but validates the steps and availability of backups
restore_to_timestamp: Option<Time>RestoreToTimestamp, if given, requested an inremental restore up to (and excluding) the given timestamp. RestoreToTimestamp and RestoreToPos are mutually exclusive.