pub struct TableDefinition {
pub name: String,
pub schema: String,
pub columns: Vec<String>,
pub primary_key_columns: Vec<String>,
pub type: String,
pub data_length: u64,
pub row_count: u64,
pub fields: Vec<Field>,
}Fields
name: Stringthe table name
schema: Stringthe SQL to run to create the table
columns: Vec<String>the columns in the order that will be used to dump and load the data
primary_key_columns: Vec<String>the primary key columns in the primary key order
type: Stringtype is either mysqlctl.TableBaseTable or mysqlctl.TableView
data_length: u64how much space the data file takes.
row_count: u64approximate number of rows
fields: Vec<Field>column names along with their types. NOTE: this is a superset of columns.