pub struct UpdateVReplicationWorkflowRequest {
pub workflow: String,
pub cells: Vec<String>,
pub tablet_types: Vec<i32>,
pub tablet_selection_preference: i32,
pub on_ddl: i32,
pub state: i32,
}Fields
workflow: Stringcells: Vec<String>tablet_types: Vec<i32>tablet_selection_preference: i32on_ddl: i32state: i32Implementations
Sourceimpl UpdateVReplicationWorkflowRequest
impl UpdateVReplicationWorkflowRequest
Sourcepub fn tablet_types(
&self,
) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<TabletType>>
pub fn tablet_types( &self, ) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<TabletType>>
Returns an iterator which yields the valid enum values contained in tablet_types.
Sourcepub fn push_tablet_types(&mut self, value: TabletType)
pub fn push_tablet_types(&mut self, value: TabletType)
Appends the provided enum value to tablet_types.
Sourcepub fn tablet_selection_preference(&self) -> TabletSelectionPreference
pub fn tablet_selection_preference(&self) -> TabletSelectionPreference
Returns the enum value of tablet_selection_preference, or the default if the field is set to an invalid enum value.
Sourcepub fn set_tablet_selection_preference(
&mut self,
value: TabletSelectionPreference,
)
pub fn set_tablet_selection_preference( &mut self, value: TabletSelectionPreference, )
Sets tablet_selection_preference to the provided enum value.
Sourcepub fn on_ddl(&self) -> OnDdlAction
pub fn on_ddl(&self) -> OnDdlAction
Returns the enum value of on_ddl, or the default if the field is set to an invalid enum value.
Sourcepub fn set_on_ddl(&mut self, value: OnDdlAction)
pub fn set_on_ddl(&mut self, value: OnDdlAction)
Sets on_ddl to the provided enum value.
Sourcepub fn state(&self) -> VReplicationWorkflowState
pub fn state(&self) -> VReplicationWorkflowState
Returns the enum value of state, or the default if the field is set to an invalid enum value.
Sourcepub fn set_state(&mut self, value: VReplicationWorkflowState)
pub fn set_state(&mut self, value: VReplicationWorkflowState)
Sets state to the provided enum value.