pub struct VDiffCoreOptions {
pub tables: String,
pub auto_retry: bool,
pub max_rows: i64,
pub checksum: bool,
pub sample_pct: i64,
pub timeout_seconds: i64,
pub max_extra_rows_to_compare: i64,
pub update_table_stats: bool,
}Fields
tables: Stringauto_retry: boolmax_rows: i64checksum: boolsample_pct: i64timeout_seconds: i64max_extra_rows_to_compare: i64update_table_stats: boolTrait Implementations
Sourceimpl Clone for VDiffCoreOptions
impl Clone for VDiffCoreOptions
Sourcefn clone(&self) -> VDiffCoreOptions
fn clone(&self) -> VDiffCoreOptions
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VDiffCoreOptions
impl Debug for VDiffCoreOptions
Sourceimpl Default for VDiffCoreOptions
impl Default for VDiffCoreOptions
Sourceimpl Message for VDiffCoreOptions
impl Message for VDiffCoreOptions
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode<B>(buf: B) -> Result<Self, DecodeError>
fn decode<B>(buf: B) -> Result<Self, DecodeError>
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
fn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for VDiffCoreOptions
impl PartialEq for VDiffCoreOptions
impl StructuralPartialEq for VDiffCoreOptions