pub struct Table {
pub type: String,
pub column_vindexes: Vec<ColumnVindex>,
pub auto_increment: Option<AutoIncrement>,
pub columns: Vec<Column>,
pub pinned: String,
pub column_list_authoritative: bool,
pub source: String,
}Expand description
Table is the table info for a Keyspace.
Fields
type: StringIf the table is a sequence, type must be “sequence”.
If the table is a reference, type must be “reference”. See https://vitess.io/docs/reference/features/vschema/#reference-tables.
Otherwise, it should be empty.
column_vindexes: Vec<ColumnVindex>column_vindexes associates columns to vindexes.
auto_increment: Option<AutoIncrement>auto_increment is specified if a column needs to be associated with a sequence.
columns: Vec<Column>columns lists the columns for the table.
pinned: Stringpinned pins an unsharded table to a specific shard, as dictated by the keyspace id. The keyspace id is represented in hex form like in keyranges.
column_list_authoritative is set to true if columns is an authoritative list for the table. This allows us to expand ‘select *’ expressions.
source: Stringreference tables may optionally indicate their source table.