pub struct GetBackupsRequest {
pub cluster_ids: Vec<String>,
pub keyspaces: Vec<String>,
pub keyspace_shards: Vec<String>,
pub request_options: Option<GetBackupsRequest>,
}Fields
cluster_ids: Vec<String>keyspaces: Vec<String>Keyspaces, if set, limits backups to just the specified keyspaces. Applies to all clusters in the request.
keyspace_shards: Vec<String>KeyspaceShards, if set, limits backups to just the specified keyspace/shards. Applies to all clusters in the request.
This field takes precedence over Keyspaces. If KeyspaceShards is set, Keyspaces is ignored.
request_options: Option<GetBackupsRequest>RequestOptions controls the per-shard request options when making GetBackups requests to vtctlds. Note that the Keyspace and Shard fields of this field are ignored; it is used only to specify Limit and Detailed fields.