pub struct GetSrvKeyspacesRequest {
pub cluster_ids: Vec<String>,
pub cells: Vec<String>,
}Fields
cluster_ids: Vec<String>An optional list of cluster IDs to filter specific clusters
cells: Vec<String>Cells is a list of cells to lookup a SrvKeyspace for. Leaving this empty is equivalent to specifying all cells in the topo.