pub struct GetTabletRequest {
pub alias: Option<TabletAlias>,
pub cluster_ids: Vec<String>,
}Fields
alias: Option<TabletAlias>Unique (per cluster) tablet alias.
cluster_ids: Vec<String>ClusterIDs is an optional parameter to narrow the scope of the search, if the caller knows which cluster the tablet may be in, or, to disambiguate if multiple clusters have a tablet with the same hostname.