pub struct ReloadSchemasResponse {
pub keyspace_results: Vec<KeyspaceResult>,
pub shard_results: Vec<ShardResult>,
pub tablet_results: Vec<TabletResult>,
}Fields
keyspace_results: Vec<KeyspaceResult>KeyspaceResults is the list of KeyspaceResult objects for a ReloadSchemas operation. It is only set when the request mandates Keyspaces mode (see ReloadSchemasRequest).
shard_results: Vec<ShardResult>ShardResults is the list of ShardResult objects for a ReloadSchemas operation. It is only set when the request mandates KeyspaceShards mode (see ReloadSchemasRequest).
tablet_results: Vec<TabletResult>TabletResults is the list of TabletResult objects for a ReloadSchemas operation. It is only set when the request mandates Tablets mode (see ReloadSchemasRequest).