pub struct Tablet {
pub cluster: Option<Cluster>,
pub tablet: Option<Tablet>,
pub state: i32,
pub fqdn: String,
}Expand description
Tablet groups the topo information of a tablet together with the Vitess cluster it belongs to.
Fields
cluster: Option<Cluster>tablet: Option<Tablet>state: i32fqdn: StringImplementations
Sourceimpl Tablet
impl Tablet
Sourcepub fn state(&self) -> ServingState
pub fn state(&self) -> ServingState
Returns the enum value of state, or the default if the field is set to an invalid enum value.
Sourcepub fn set_state(&mut self, value: ServingState)
pub fn set_state(&mut self, value: ServingState)
Sets state to the provided enum value.