pub struct CreateKeyspaceRequest {
pub name: String,
pub force: bool,
pub allow_empty_v_schema: bool,
pub served_froms: Vec<ServedFrom>,
pub type: i32,
pub base_keyspace: String,
pub snapshot_time: Option<Time>,
pub durability_policy: String,
pub sidecar_db_name: String,
}Fields
name: StringName is the name of the keyspace.
force: boolForce proceeds with the request even if the keyspace already exists.
allow_empty_v_schema: boolAllowEmptyVSchema allows a keyspace to be created with no vschema.
served_froms: Vec<ServedFrom>ServedFroms specifies a set of db_type:keyspace pairs used to serve traffic for the keyspace.
type: i32Type is the type of the keyspace to create.
base_keyspace: StringBaseKeyspace specifies the base keyspace for SNAPSHOT keyspaces. It is required to create a SNAPSHOT keyspace.
snapshot_time: Option<Time>SnapshotTime specifies the snapshot time for this keyspace. It is required to create a SNAPSHOT keyspace.
durability_policy: StringDurabilityPolicy is the durability policy to be used for this keyspace.
sidecar_db_name: StringSidecarDBName is the name of the sidecar database that each vttablet in the keyspace will use.
Implementations
Sourceimpl CreateKeyspaceRequest
impl CreateKeyspaceRequest
Sourcepub fn type(&self) -> KeyspaceType
pub fn type(&self) -> KeyspaceType
Returns the enum value of type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_type(&mut self, value: KeyspaceType)
pub fn set_type(&mut self, value: KeyspaceType)
Sets type to the provided enum value.