pub struct ReloadSchemaKeyspaceRequest {
pub keyspace: String,
pub wait_position: String,
pub include_primary: bool,
pub concurrency: u32,
}Fields
keyspace: Stringwait_position: Stringinclude_primary: boolconcurrency: u32Concurrency is the global concurrency across all shards in the keyspace (so, at most this many tablets will be reloaded across the keyspace at any given point).