#[repr(i32)]pub enum CommitOrder {
Normal = 0,
Pre = 1,
Post = 2,
Autocommit = 3,
}Expand description
CommitOrder is used to designate which of the ShardSessions get used for transactions.
Variants
Normal = 0
NORMAL is the default commit order.
Pre = 1
PRE is used to designate pre_sessions.
Post = 2
POST is used to designate post_sessions.
Autocommit = 3
AUTOCOMMIT is used to run the statement as autocommitted transaction.
Implementations
Sourceimpl CommitOrder
impl CommitOrder
Sourceimpl CommitOrder
impl CommitOrder
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.