#[repr(i32)]pub enum TransactionMode {
Unspecified = 0,
Single = 1,
Multi = 2,
Twopc = 3,
}Expand description
TransactionMode controls the execution of distributed transaction across multiple shards.
Variants
Unspecified = 0
UNSPECIFIED uses the transaction mode set by the VTGate flag ‘transaction_mode’.
Single = 1
SINGLE disallows distributed transactions.
Multi = 2
MULTI allows distributed transactions with best effort commit.
Twopc = 3
TWOPC is for distributed transactions with atomic commits.
Implementations
Sourceimpl TransactionMode
impl TransactionMode
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.