pub struct VStreamFlags {
pub minimize_skew: bool,
pub heartbeat_interval: u32,
pub stop_on_reshard: bool,
pub cells: String,
pub cell_preference: String,
pub tablet_order: String,
}Fields
minimize_skew: boolalign streams
heartbeat_interval: u32how often heartbeats must be sent when idle (seconds)
stop_on_reshard: boolstop streams on a reshard (journal event)
cells: Stringif specified, these cells (comma-separated) are used to pick source tablets from. defaults to the cell of the vtgate serving the VStream API.
cell_preference: Stringtablet_order: StringTrait Implementations
Sourceimpl Clone for VStreamFlags
impl Clone for VStreamFlags
Sourcefn clone(&self) -> VStreamFlags
fn clone(&self) -> VStreamFlags
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VStreamFlags
impl Debug for VStreamFlags
Sourceimpl Default for VStreamFlags
impl Default for VStreamFlags
Sourceimpl Message for VStreamFlags
impl Message for VStreamFlags
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode<B>(buf: B) -> Result<Self, DecodeError>
fn decode<B>(buf: B) -> Result<Self, DecodeError>
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
fn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for VStreamFlags
impl PartialEq for VStreamFlags
impl StructuralPartialEq for VStreamFlags