pub struct VStreamRequest {
pub caller_id: Option<CallerId>,
pub tablet_type: i32,
pub vgtid: Option<VGtid>,
pub filter: Option<Filter>,
pub flags: Option<VStreamFlags>,
}Expand description
VStreamRequest is the payload for VStream.
Fields
caller_id: Option<CallerId>tablet_type: i32vgtid: Option<VGtid>position specifies the starting point of the bin log positions as well as the keyspace-shards to pull events from. position is of the form ‘ks1:0@MySQL56/<mysql_pos>|ks2:-80@MySQL56/<mysql_pos>’.
filter: Option<Filter>flags: Option<VStreamFlags>Implementations
Sourceimpl VStreamRequest
impl VStreamRequest
Sourcepub fn tablet_type(&self) -> TabletType
pub fn tablet_type(&self) -> TabletType
Returns the enum value of tablet_type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_tablet_type(&mut self, value: TabletType)
pub fn set_tablet_type(&mut self, value: TabletType)
Sets tablet_type to the provided enum value.