pub struct RpcError {
pub message: String,
pub code: i32,
}Expand description
RPCError is an application-level error structure returned by VtTablet (and passed along by VtGate if appropriate). We use this so the clients don’t have to parse the error messages, but instead can depend on the value of the code.
Fields
message: Stringcode: i32Implementations