#[repr(i32)]pub enum WorkflowState {
NotStarted = 0,
Running = 1,
Done = 2,
}Expand description
WorkflowState describes the state of a workflow. This constant should match the Node object described in web/vtctld2/src/app/workflows/node.ts as it is exposed as JSON to the Angular 2 web app.
Variants
Implementations
Sourceimpl WorkflowState
impl WorkflowState
Sourceimpl WorkflowState
impl WorkflowState
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.