Struct WorkflowCheckpoint

pub struct WorkflowCheckpoint {
    pub code_version: i32,
    pub tasks: HashMap<String, Task>,
    pub settings: HashMap<String, String>,
}

Fields

code_version: i32

code_version is used to detect incompabilities between the version of the running workflow and the one which wrote the checkpoint. If they don’t match, the workflow must not continue. The author of workflow must update this variable in their implementation when incompabilities are introduced.

tasks stores all tasks of the workflow in a map. The key is a unique name to identify the task, e.g. clone/-80.

tasks: HashMap<String, Task>

Task is the data structure that stores the execution status and the attributes of a task.

settings: HashMap<String, String>

settings includes workflow specific data, e.g. the resharding workflow would store the source shards and destination shards.