pub struct BinlogSource {
pub keyspace: String,
pub shard: String,
pub tablet_type: i32,
pub key_range: Option<KeyRange>,
pub tables: Vec<String>,
pub filter: Option<Filter>,
pub on_ddl: i32,
pub external_mysql: String,
pub stop_after_copy: bool,
pub external_cluster: String,
pub source_time_zone: String,
pub target_time_zone: String,
}Expand description
BinlogSource specifies the source and filter parameters for Filtered Replication. KeyRange and Tables are legacy. Filter is the new way to specify the filtering rules.
Fields
keyspace: Stringthe source keyspace
shard: Stringthe source shard
tablet_type: i32the source tablet type
key_range: Option<KeyRange>KeyRange is set if the request is for a keyrange
tables: Vec<String>Tables is set if the request is for a list of tables
filter: Option<Filter>Filter is set if we’re using the generalized representation for the filter.
on_ddl: i32OnDdl specifies the action to be taken when a DDL is encountered.
external_mysql: StringSource is an external mysql. This attribute should be set to the username to use in the connection
stop_after_copy: boolStopAfterCopy specifies if vreplication should be stopped after copying is done.
external_cluster: StringExternalCluster is the name of the mounted cluster which has the source keyspace/db for this workflow it is of the type <cluster_type.cluster_name>
source_time_zone: StringSourceTimeZone is the time zone in which datetimes on the source were stored, provided as an option in MoveTables
target_time_zone: StringTargetTimeZone is not currently specifiable by the user, defaults to UTC for the forward workflows and to the SourceTimeZone in reverse workflows
Implementations
Sourceimpl BinlogSource
impl BinlogSource
Sourcepub fn tablet_type(&self) -> TabletType
pub fn tablet_type(&self) -> TabletType
Returns the enum value of tablet_type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_tablet_type(&mut self, value: TabletType)
pub fn set_tablet_type(&mut self, value: TabletType)
Sets tablet_type to the provided enum value.
Sourcepub fn on_ddl(&self) -> OnDdlAction
pub fn on_ddl(&self) -> OnDdlAction
Returns the enum value of on_ddl, or the default if the field is set to an invalid enum value.
Sourcepub fn set_on_ddl(&mut self, value: OnDdlAction)
pub fn set_on_ddl(&mut self, value: OnDdlAction)
Sets on_ddl to the provided enum value.