pub struct Journal {
pub id: i64,
pub migration_type: i32,
pub tables: Vec<String>,
pub local_position: String,
pub shard_gtids: Vec<ShardGtid>,
pub participants: Vec<KeyspaceShard>,
pub source_workflows: Vec<String>,
}Expand description
Journal contains the metadata for a journal event. The commit of a journal event indicates the point of no return for a migration.
Fields
id: i64Id represents a unique journal id.
migration_type: i32tables: Vec<String>Tables is set if the journal represents a TABLES migration.
local_position: StringLocalPosition is the source position at which the migration happened.
shard_gtids: Vec<ShardGtid>ShardGtids is the list of targets to which the migration took place.
participants: Vec<KeyspaceShard>Participants is the list of source participants for a migration. Every participant is expected to have an identical journal entry. While streaming, the client must wait for the journal entry to be received from all pariticipants, and then replace them with new streams specified by ShardGtid. If a stream does not have all participants, a consistent migration is not possible.
source_workflows: Vec<String>SourceWorkflows is the list of workflows in the source shard that were migrated to the target. If a migration fails after a Journal is committed, this information is used to start the target streams that were created prior to the creation of the journal.
Implementations
Sourceimpl Journal
impl Journal
Sourcepub fn migration_type(&self) -> MigrationType
pub fn migration_type(&self) -> MigrationType
Returns the enum value of migration_type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_migration_type(&mut self, value: MigrationType)
pub fn set_migration_type(&mut self, value: MigrationType)
Sets migration_type to the provided enum value.