pub struct CreateVReplicationWorkflowRequest {
pub workflow: String,
pub binlog_source: Vec<BinlogSource>,
pub cells: Vec<String>,
pub tablet_types: Vec<i32>,
pub tablet_selection_preference: i32,
pub workflow_type: i32,
pub workflow_sub_type: i32,
pub defer_secondary_keys: bool,
pub auto_start: bool,
pub stop_after_copy: bool,
}Fields
workflow: Stringbinlog_source: Vec<BinlogSource>cells: Vec<String>Optional parameters.
tablet_types: Vec<i32>TabletTypes is the list of tablet types to use when selecting source tablets.
tablet_selection_preference: i32workflow_type: i32workflow_sub_type: i32defer_secondary_keys: boolDeferSecondaryKeys specifies if secondary keys should be created in one shot after table copy finishes.
auto_start: boolAutoStart specifies if the workflow should be started when created.
stop_after_copy: boolShould the workflow stop after the copy phase.
Implementations
Sourceimpl CreateVReplicationWorkflowRequest
impl CreateVReplicationWorkflowRequest
Sourcepub fn tablet_types(
&self,
) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<TabletType>>
pub fn tablet_types( &self, ) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<TabletType>>
Returns an iterator which yields the valid enum values contained in tablet_types.
Sourcepub fn push_tablet_types(&mut self, value: TabletType)
pub fn push_tablet_types(&mut self, value: TabletType)
Appends the provided enum value to tablet_types.
Sourcepub fn tablet_selection_preference(&self) -> TabletSelectionPreference
pub fn tablet_selection_preference(&self) -> TabletSelectionPreference
Returns the enum value of tablet_selection_preference, or the default if the field is set to an invalid enum value.
Sourcepub fn set_tablet_selection_preference(
&mut self,
value: TabletSelectionPreference,
)
pub fn set_tablet_selection_preference( &mut self, value: TabletSelectionPreference, )
Sets tablet_selection_preference to the provided enum value.
Sourcepub fn workflow_type(&self) -> VReplicationWorkflowType
pub fn workflow_type(&self) -> VReplicationWorkflowType
Returns the enum value of workflow_type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_workflow_type(&mut self, value: VReplicationWorkflowType)
pub fn set_workflow_type(&mut self, value: VReplicationWorkflowType)
Sets workflow_type to the provided enum value.
Sourcepub fn workflow_sub_type(&self) -> VReplicationWorkflowSubType
pub fn workflow_sub_type(&self) -> VReplicationWorkflowSubType
Returns the enum value of workflow_sub_type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_workflow_sub_type(&mut self, value: VReplicationWorkflowSubType)
pub fn set_workflow_sub_type(&mut self, value: VReplicationWorkflowSubType)
Sets workflow_sub_type to the provided enum value.