pub struct GetWorkflowsRequest {
pub cluster_ids: Vec<String>,
pub active_only: bool,
pub keyspaces: Vec<String>,
pub ignore_keyspaces: Vec<String>,
}Fields
cluster_ids: Vec<String>active_only: boolActiveOnly specifies whether to return workflows that are currently active (running or paused) instead of all workflows.
keyspaces: Vec<String>Keyspaces is a list of keyspaces to restrict the workflow search to. Note that the keyspaces list applies across all cluster IDs in the request.
If, for example, you have two clusters, each with a keyspace called “foo” and want the workflows from “foo” in cluster1 but not from cluster2, you must make two requests.
Keyspaces and IgnoreKeyspaces are mutually-exclusive, and Keyspaces takes precedence; if Keyspaces is a non-empty list, then IgnoreKeyspaces is ignored completely.
ignore_keyspaces: Vec<String>IgnoreKeyspaces is a list of keyspaces to skip during the workflow search. It has the same semantics as the Keyspaces parameter, so refer to that documentation for more details.