pub struct ReloadSchemasRequest {
pub keyspaces: Vec<String>,
pub keyspace_shards: Vec<String>,
pub tablets: Vec<TabletAlias>,
pub cluster_ids: Vec<String>,
pub concurrency: u32,
pub wait_position: String,
pub include_primary: bool,
}Fields
keyspaces: Vec<String>Keyspaces, if set, will reload schemas across one or more keyspaces. A keyspace not existing in a cluster will not fail the overall request.
Superceded by KeyspaceShards and Tablets, in that order.
keyspace_shards: Vec<String>KeyspaceShards, if set, will reload schemas across one or more shards. Each element must be a valid keyspace/shard according to topoproto.ParseKeyspaceShard. A shard not existing in a cluster will not fail the overall request.
Supercedes Keyspaces, and is superceded by Tablets.
tablets: Vec<TabletAlias>Tablets, if set will reload schemas across one or more tablets. Supercedes both Keyspaces and KeyspaceShards.
cluster_ids: Vec<String>ClusterIds optionally restricts the reload operation to clusters with the specified IDs. An empty list of ClusterIds will operate on all clusters.
concurrency: u32Concurrency controls the number of tablets to reload at any given time. Its semantics depend on whether the request is for keyspace, shard, or tablet mode.
In Keyspaces mode, Concurrency is the number of tablets to reload at once per keyspace.
In KeyspaceShards mode, Concurrency is the number of tablets to reload at once per shard.
In Tablets mode, Concurrency is the number of tablets to reload at once per cluster.
wait_position: StringWaitPosition is the replication position that replicating tablets should reach prior to reloading their schemas.
Does not apply in Tablets mode.
include_primary: boolIncludePrimary, if set, will reload the schemas on PRIMARY tablets as well as REPLICA and RDONLY.
Does not apply in Tablets mode.