#[repr(i32)]pub enum Code {
Show 19 variants
Ok = 0,
Canceled = 1,
Unknown = 2,
InvalidArgument = 3,
DeadlineExceeded = 4,
NotFound = 5,
AlreadyExists = 6,
PermissionDenied = 7,
ResourceExhausted = 8,
FailedPrecondition = 9,
Aborted = 10,
OutOfRange = 11,
Unimplemented = 12,
Internal = 13,
Unavailable = 14,
DataLoss = 15,
Unauthenticated = 16,
ClusterEvent = 17,
ReadOnly = 18,
}Expand description
Code represents canonical error codes. The names, numbers and comments must match the ones defined by grpc (0-16): https://godoc.org/google.golang.org/grpc/codes. 17+ are custom codes
Variants
Ok = 0
OK is returned on success.
Canceled = 1
CANCELED indicates the operation was cancelled (typically by the caller).
Unknown = 2
UNKNOWN error. An example of where this error may be returned is if a Status value received from another address space belongs to an error-space that is not known in this address space. Also errors raised by APIs that do not return enough error information may be converted to this error.
InvalidArgument = 3
INVALID_ARGUMENT indicates client specified an invalid argument. Note that this differs from FAILED_PRECONDITION. It indicates arguments that are problematic regardless of the state of the system (e.g., a malformed file name).
DeadlineExceeded = 4
DEADLINE_EXCEEDED means operation expired before completion. For operations that change the state of the system, this error may be returned even if the operation has completed successfully. For example, a successful response from a server could have been delayed long enough for the deadline to expire.
NotFound = 5
NOT_FOUND means some requested entity (e.g., file or directory) was not found.
AlreadyExists = 6
ALREADY_EXISTS means an attempt to create an entity failed because one already exists.
PermissionDenied = 7
PERMISSION_DENIED indicates the caller does not have permission to execute the specified operation. It must not be used for rejections caused by exhausting some resource (use RESOURCE_EXHAUSTED instead for those errors). It must not be used if the caller cannot be identified (use Unauthenticated instead for those errors).
ResourceExhausted = 8
RESOURCE_EXHAUSTED indicates some resource has been exhausted, perhaps a per-user quota, or perhaps the entire file system is out of space.
FailedPrecondition = 9
FAILED_PRECONDITION indicates operation was rejected because the system is not in a state required for the operation’s execution. For example, directory to be deleted may be non-empty, an rmdir operation is applied to a non-directory, etc.
A litmus test that may help a service implementor in deciding between FAILED_PRECONDITION, ABORTED, and UNAVAILABLE: (a) Use UNAVAILABLE if the client can retry just the failing call. (b) Use ABORTED if the client should retry at a higher-level (e.g., restarting a read-modify-write sequence). (c) Use FAILED_PRECONDITION if the client should not retry until the system state has been explicitly fixed. E.g., if an “rmdir” fails because the directory is non-empty, FAILED_PRECONDITION should be returned since the client should not retry unless they have first fixed up the directory by deleting files from it. (d) Use FAILED_PRECONDITION if the client performs conditional REST Get/Update/Delete on a resource and the resource on the server does not match the condition. E.g., conflicting read-modify-write on the same resource.
Aborted = 10
ABORTED indicates the operation was aborted, typically due to a concurrency issue like sequencer check failures, transaction aborts, etc.
See litmus test above for deciding between FAILED_PRECONDITION, ABORTED, and UNAVAILABLE.
OutOfRange = 11
OUT_OF_RANGE means operation was attempted past the valid range. E.g., seeking or reading past end of file.
Unlike INVALID_ARGUMENT, this error indicates a problem that may be fixed if the system state changes. For example, a 32-bit file system will generate INVALID_ARGUMENT if asked to read at an offset that is not in the range [0,2^32-1], but it will generate OUT_OF_RANGE if asked to read from an offset past the current file size.
There is a fair bit of overlap between FAILED_PRECONDITION and OUT_OF_RANGE. We recommend using OUT_OF_RANGE (the more specific error) when it applies so that callers who are iterating through a space can easily look for an OUT_OF_RANGE error to detect when they are done.
Unimplemented = 12
UNIMPLEMENTED indicates operation is not implemented or not supported/enabled in this service.
Internal = 13
INTERNAL errors. Means some invariants expected by underlying system has been broken. If you see one of these errors, something is very broken.
UNAVAILABLE indicates the service is currently unavailable. This is a most likely a transient condition and may be corrected by retrying with a backoff.
See litmus test above for deciding between FAILED_PRECONDITION, ABORTED, and UNAVAILABLE.
DataLoss = 15
DATA_LOSS indicates unrecoverable data loss or corruption.
Unauthenticated = 16
UNAUTHENTICATED indicates the request does not have valid authentication credentials for the operation.
ClusterEvent = 17
CLUSTER_EVENT indicates that a cluster operation might be in effect
ReadOnly = 18
Topo server connection is read-only
Implementations
Sourceimpl Code
impl Code
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.